==> haskell-floskell-0.10.8-81-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-floskell.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 floskell
version:              0.10.8
visibility:           public
id:                   floskell-0.10.8-66ltCJxErcuB4w26PSCxs7
key:                  floskell-0.10.8-66ltCJxErcuB4w26PSCxs7
license:              BSD-3-Clause
copyright:
    2014 Chris Done, 2015 Andrew Gibiansky, 2016-2023 Enno Cramer

maintainer:           ecramer@memfrob.de
author:
    Chris Done, Andrew Gibiansky, Tobias Pflug, Pierre Radermecker, Enno Cramer

stability:            Unstable
homepage:             https://github.com/ennocramer/floskell
synopsis:             A flexible Haskell source code pretty printer
description:
    A flexible Haskell source code pretty printer.

    See the Github page for usage\/explanation: <https://github.com/ennocramer/floskell>

category:             Development
abi:                  1a364c0da89f0e528bf54f419850e708
exposed:              True
exposed-modules:
    Floskell Floskell.Attoparsec Floskell.Buffer Floskell.Comments
    Floskell.Config Floskell.ConfigFile Floskell.Fixities
    Floskell.Imports Floskell.Pretty Floskell.Printers Floskell.Styles
    Floskell.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/floskell-0.10.8
library-dirs:         /usr/lib/ghc-9.4.8/site-local/floskell-0.10.8
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/floskell-0.10.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-floskell
hs-libraries:         HSfloskell-0.10.8-66ltCJxErcuB4w26PSCxs7
depends:
    aeson-2.1.2.1-JtwfP0wSn8NCfmI6cbJvU2
    attoparsec-0.14.4-5WJushYcFmLGCbqKFNMNd6 base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi directory-1.3.7.1
    filepath-1.4.2.2 haskell-src-exts-1.23.1-9jxJyODyFUQGwY9RXcmgHr
    monad-dijkstra-0.1.1.5-LLNrxY7b7Sz2RtSStXVF8p mtl-2.2.2 text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-I6MqYi1ZitpKUe3ww5yyKM
    utf8-string-1.0.2-FnO1h94XkEn7naEuvLflUO

haddock-interfaces:   /usr/share/doc/haskell-floskell/html/floskell.haddock
haddock-html:         /usr/share/doc/haskell-floskell/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-floskell-0.10.8-82-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-floskell.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 floskell
version:              0.10.8
visibility:           public
id:                   floskell-0.10.8-aZjAPkeEGQ8spK9oNFLIA
key:                  floskell-0.10.8-aZjAPkeEGQ8spK9oNFLIA
license:              BSD-3-Clause
copyright:
    2014 Chris Done, 2015 Andrew Gibiansky, 2016-2023 Enno Cramer

maintainer:           ecramer@memfrob.de
author:
    Chris Done, Andrew Gibiansky, Tobias Pflug, Pierre Radermecker, Enno Cramer

stability:            Unstable
homepage:             https://github.com/ennocramer/floskell
synopsis:             A flexible Haskell source code pretty printer
description:
    A flexible Haskell source code pretty printer.

    See the Github page for usage\/explanation: <https://github.com/ennocramer/floskell>

category:             Development
abi:                  40e25aefe6188793b57ac05ebb097620
exposed:              True
exposed-modules:
    Floskell Floskell.Attoparsec Floskell.Buffer Floskell.Comments
    Floskell.Config Floskell.ConfigFile Floskell.Fixities
    Floskell.Imports Floskell.Pretty Floskell.Printers Floskell.Styles
    Floskell.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/floskell-0.10.8
library-dirs:         /usr/lib/ghc-9.4.8/site-local/floskell-0.10.8
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/floskell-0.10.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-floskell
hs-libraries:         HSfloskell-0.10.8-aZjAPkeEGQ8spK9oNFLIA
depends:
    aeson-2.1.2.1-6acn88DzD1XA00qNRJAJcm
    attoparsec-0.14.4-HXvPhgAZIYuDm9YtcrLhPL base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi directory-1.3.7.1
    filepath-1.4.2.2 haskell-src-exts-1.23.1-BhJSyKUIY044HNlgcezRJT
    monad-dijkstra-0.1.1.5-8qq5Ll0e7lX2RfffOEWRFr mtl-2.2.2 text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-2kG5VEC3Gy42AwINT9WJ9w
    utf8-string-1.0.2-FnO1h94XkEn7naEuvLflUO

haddock-interfaces:   /usr/share/doc/haskell-floskell/html/floskell.haddock
haddock-html:         /usr/share/doc/haskell-floskell/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
